@@ -1,14 +1,19 @@
-import { is, type, equal, match, throws } from 'uvu/assert'
-import { spyOn, restoreAll } from 'nanospy'
+import { restoreAll, spyOn } from 'nanospy'
 import { test } from 'uvu'
+import { equal, is, match, throws, type } from 'uvu/assert'
 
-import postcss, { Root, PluginCreator } from '../lib/postcss.js'
+import postcss = require('../lib/postcss.js')
+import postcssDefault, { PluginCreator, Root } from '../lib/postcss.js'
 import Processor from '../lib/processor.js'
 
 test.after.each(() => {
   restoreAll()
 })
 
+test('default matches module.exports', () => {
+  is(postcss, postcssDefault)
+})
+
 test('creates plugins list', () => {
   let processor = postcss()
   is(processor instanceof Processor, true)
@@ -107,7 +112,7 @@ test('contains list module', () => {
 
 test('works with null', () => {
   throws(() => {
-    // @ts-expect-error
+    // @ts-expect-error Testing invalid input
     postcss([() => {}]).process(null).css
   }, /PostCSS received null instead of CSS string/)
 })
